@@ -18,7 +18,7 @@
 
 /* $Id: build-defs.h.in,v 1.11 2002/10/04 04:47:34 rasmus Exp $ */
 
-#define CONFIGURE_COMMAND " './configure' '--prefix=/usr' '--disable-static' '--with-apxs=/usr/sbin/apxs' '--enable-discard-path' '--with-config-file-path=/etc/apache' '--enable-safe-mode' '--with-openssl' '--enable-bcmath' '--with-bz2' '--enable-pic' '--enable-calendar' '--enable-ctype' '--with-gdbm' '--with-db2' '--with-db3' '--with-imap-ssl=/tmp/pine4.52/imap/c-client' '--with-imap=/tmp/pine4.52/imap/c-client' '--enable-dbase' '--enable-ftp' '--enable-gd-imgstrttf' '--with-gd=/tmp/gd-1.8.4' '--with-jpeg-dir=/tmp/gd-1.8.4' '--with-png-dir=/tmp/gd-1.8.4' '--with-gmp' '--with-mysql=shared,/usr' '--with-xml=shared' '--with-mm=/usr' '--enable-trans-sid' '--enable-shmop' '--enable-sockets' '--with-regex=php' '--enable-sysvsem' '--enable-sysvshm' '--enable-yp' '--enable-memory-limit' '--with-tsrm-pthreads' '--enable-shared' '--disable-debug' '--with-zlib=/usr'"
+#define CONFIGURE_COMMAND " './configure' '--prefix=/usr' '--disable-static' '--with-apxs=/usr/sbin/apxs' '--enable-discard-path' '--with-config-file-path=/etc/apache' '--enable-safe-mode' '--with-openssl' '--enable-bcmath' '--with-bz2' '--with-pic' '--enable-calendar' '--enable-ctype' '--with-gdbm' '--with-db2' '--with-db3' '--with-imap-ssl=/tmp/pine4.53/imap/c-client' '--with-imap=/tmp/pine4.53/imap/c-client' '--enable-dbase' '--enable-ftp' '--with-gd' '--enable-gd-native-ttf' '--with-jpeg-dir=/usr' '--with-png' '--with-gmp' '--with-mysql=shared,/usr' '--with-xml=shared,/usr' '--with-mm=/usr' '--enable-trans-sid' '--enable-shmop' '--enable-sockets' '--with-regex=php' '--enable-sysvsem' '--enable-sysvshm' '--enable-yp' '--enable-memory-limit' '--with-tsrm-pthreads' '--enable-shared' '--disable-debug' '--with-zlib=/usr'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
